==> haskell-tls-session-manager-0.0.5-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.5
visibility:           public
id:                   tls-session-manager-0.0.5-9j8fiUjW0Uw4pYoNS2PZx7
key:                  tls-session-manager-0.0.5-9j8fiUjW0Uw4pYoNS2PZx7
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session DB and session ticket
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance and session ticket manager

category:             Web
abi:                  e30328018e4842a968b45788d9d8ceb7
exposed:              True
exposed-modules:      Network.TLS.SessionManager Network.TLS.SessionTicket
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.5-9j8fiUjW0Uw4pYoNS2PZx7
depends:
    auto-update-0.1.6-LlVRr0TLjkdDwdz2uDRmdx base-4.17.2.1
    basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7 bytestring-0.11.5.3
    clock-0.8.4-ATRiwEs5nFD36IAH76nrve
    crypto-token-0.1.1-GlzLqlwgxN6785pGAUSZN4
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    psqueues-0.2.8.2-2kD9GvNydpvJunlzowVdVw
    serialise-0.2.6.1-BVcgehS2dAx1Y5WK4jTFft
    tls-2.0.6-8ShAFN7vmeS16JR2x2asj8

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.5-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.5
visibility:           public
id:                   tls-session-manager-0.0.5-B0ZBgQsgb2XLt6SIWKkirX
key:                  tls-session-manager-0.0.5-B0ZBgQsgb2XLt6SIWKkirX
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session DB and session ticket
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance and session ticket manager

category:             Web
abi:                  b18e603e51b98ade6404cbfed8a6ecc9
exposed:              True
exposed-modules:      Network.TLS.SessionManager Network.TLS.SessionTicket
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.5-B0ZBgQsgb2XLt6SIWKkirX
depends:
    auto-update-0.1.6-CRDIDCa093777oh8r2dtw6 base-4.17.2.1
    basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7 bytestring-0.11.5.3
    clock-0.8.4-1MO8onMGVRH7vF3UIGYmpX
    crypto-token-0.1.1-61flj0yezOqETxZCeBIVsd
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    psqueues-0.2.8.2-6QE0hu7PanE34cAmyrORrm
    serialise-0.2.6.1-1QtatKHIm4P1mntfV0LMYj
    tls-2.0.6-L5JvRskNnEGCOdLeVQOJK5

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
